==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_results/mp0113_001/MP0113_GetDocumentAssociation_001_Result.java <==

package net.datastream.schemas.mp_results.mp0113_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0113_001}ResultData" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0113_001}InstallParameters" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData",
    "installParameters"
})
@XmlRootElement(name = "MP0113_GetDocumentAssociation_001_Result")
public class MP0113_GetDocumentAssociation_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected List<ResultData> resultData;
    @XmlElement(name = "InstallParameters")
    protected List<InstallParameters> installParameters;

    /**
     * Gets the value of the resultData property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the resultData property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getResultData().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ResultData }
     * 
     * 
     */
    public List<ResultData> getResultData() {
        if (resultData == null) {
            resultData = new ArrayList<ResultData>();
        }
        return this.resultData;
    }

    /**
     * Gets the value of the installParameters property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the installParameters property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getInstallParameters().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link InstallParameters }
     * 
     * 
     */
    public List<InstallParameters> getInstallParameters() {
        if (installParameters == null) {
            installParameters = new ArrayList<InstallParameters>();
        }
        return this.installParameters;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_results/mp0113_001/MP0113_GetDocumentAssociation_001_Result.java <==

package net.datastream.schemas.mp_results.mp0113_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0113_001}ResultData" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0113_001}InstallParameters" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData",
    "installParameters"
})
@XmlRootElement(name = "MP0113_GetDocumentAssociation_001_Result")
public class MP0113_GetDocumentAssociation_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected List<ResultData> resultData;
    @XmlElement(name = "InstallParameters")
    protected List<InstallParameters> installParameters;

    /**
     * Gets the value of the resultData property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the resultData property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getResultData().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ResultData }
     * 
     * 
     */
    public List<ResultData> getResultData() {
        if (resultData == null) {
            resultData = new ArrayList<ResultData>();
        }
        return this.resultData;
    }

    /**
     * Gets the value of the installParameters property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the installParameters property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getInstallParameters().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link InstallParameters }
     * 
     * 
     */
    public List<InstallParameters> getInstallParameters() {
        if (installParameters == null) {
            installParameters = new ArrayList<InstallParameters>();
        }
        return this.installParameters;
    }

}
